#ifndef NT2_INCLUDE_FUNCTIONS_LOGICAL_AND_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_LOGICAL_AND_HPP_INCLUDED

#include <nt2/operator/include/functions/logical_and.hpp>

#endif
